@@ -353,7 +353,13 @@ class VmdkHandle(FileHandle):
         LOG.debug("Lease for %(url)s is in state: %(state)s.",
                   {'url': self._url,
                    'state': state})
-        if state == 'ready':
+        if self._get_progress() < 100:
+            LOG.error("Aborting lease for %s due to incomplete transfer.",
+                      self._url)
+            self._session.invoke_api(self._session.vim,
+                                     'HttpNfcLeaseAbort',
+                                     self._lease)
+        elif state == 'ready':
             LOG.debug("Releasing lease for %s.", self._url)
             self._session.invoke_api(self._session.vim,
                                      'HttpNfcLeaseComplete',
@@ -486,7 +492,7 @@ class VmdkWriteHandle(VmdkHandle):
         url, thumbprint = self._find_vmdk_url(lease_info, host, port)
         self._vm_ref = lease_info.entity
 
-        cookies = session.vim.client.options.transport.cookiejar
+        cookies = session.vim.client.cookiejar
         # Create HTTP connection to write to VMDK URL
         if http_method == 'PUT':
             overwrite = 't'
@@ -506,7 +512,14 @@ class VmdkWriteHandle(VmdkHandle):
         super(VmdkWriteHandle, self).__init__(session, lease, url, self._conn)
 
     def get_imported_vm(self):
-        """"Get managed object reference of the VM created for import."""
+        """"Get managed object reference of the VM created for import.
+
+        :raises: VimException
+        """
+        if self._get_progress() < 100:
+            excep_msg = _("Incomplete VMDK upload to %s.") % self._url
+            LOG.exception(excep_msg)
+            raise exceptions.ImageTransferException(excep_msg)
         return self._vm_ref
 
     def tell(self):
@@ -543,6 +556,10 @@ class VmdkWriteHandle(VmdkHandle):
         """
         try:
             self._release_lease()
+        except exceptions.ManagedObjectNotFoundException:
+            LOG.info("Lease for %(url)s not found.  No need to release.",
+                     {'url': self._url})
+            return
         except exceptions.VimException:
             LOG.warning("Error occurred while releasing the lease "
                         "for %s.",
@@ -587,7 +604,7 @@ class VmdkReadHandle(VmdkHandle):
 
         # find URL of the VMDK file to be read and open connection
         url, thumbprint = self._find_vmdk_url(lease_info, host, port)
-        cookies = session.vim.client.options.transport.cookiejar
+        cookies = session.vim.client.cookiejar
         self._conn = self._create_read_connection(url,
                                                   cookies=cookies,
                                                   ssl_thumbprint=thumbprint)
@@ -624,6 +641,10 @@ class VmdkReadHandle(VmdkHandle):
         """
         try:
             self._release_lease()
+        except exceptions.ManagedObjectNotFoundException:
+            LOG.info("Lease for %(url)s not found.  No need to release.",
+                     {'url': self._url})
+            return
         except exceptions.VimException:
             LOG.warning("Error occurred while releasing the lease "
                         "for %s.",
