@@ -60,7 +60,7 @@ class ServiceTest(base.TestCase):
 
     def setUp(self):
         super(ServiceTest, self).setUp()
-        patcher = mock.patch('suds.client.Client')
+        patcher = mock.patch('oslo_vmware.service.CompatibilitySudsClient')
         self.addCleanup(patcher.stop)
         self.SudsClientMock = patcher.start()
 
@@ -95,8 +95,8 @@ class ServiceTest(base.TestCase):
         resp = mock.Mock()
 
         def side_effect(mo, **kwargs):
-            self.assertEqual(managed_object, mo._type)
-            self.assertEqual(managed_object, mo.value)
+            self.assertEqual(managed_object, vim_util.get_moref_type(mo))
+            self.assertEqual(managed_object, vim_util.get_moref_value(mo))
             return resp
 
         svc_obj = service.Service()
@@ -110,8 +110,8 @@ class ServiceTest(base.TestCase):
         managed_object = 'Datacenter'
 
         def side_effect(mo, **kwargs):
-            self.assertEqual(managed_object, mo._type)
-            self.assertEqual(managed_object, mo.value)
+            self.assertEqual(managed_object, vim_util.get_moref_type(mo))
+            self.assertEqual(managed_object, vim_util.get_moref_value(mo))
             return None
 
         svc_obj = service.Service()
@@ -129,8 +129,8 @@ class ServiceTest(base.TestCase):
         doc = mock.Mock()
 
         def side_effect(mo, **kwargs):
-            self.assertEqual(managed_object, mo._type)
-            self.assertEqual(managed_object, mo.value)
+            self.assertEqual(managed_object, vim_util.get_moref_type(mo))
+            self.assertEqual(managed_object, vim_util.get_moref_value(mo))
             fault = mock.Mock(faultstring="MyFault")
 
             fault_children = mock.Mock()
@@ -180,8 +180,8 @@ class ServiceTest(base.TestCase):
         doc = mock.Mock()
 
         def side_effect(mo, **kwargs):
-            self.assertEqual(managed_object, mo._type)
-            self.assertEqual(managed_object, mo.value)
+            self.assertEqual(managed_object, vim_util.get_moref_type(mo))
+            self.assertEqual(managed_object, vim_util.get_moref_value(mo))
             fault = mock.Mock(faultstring="MyFault")
 
             fault_children = mock.Mock()
@@ -215,8 +215,8 @@ class ServiceTest(base.TestCase):
         doc = mock.Mock()
 
         def side_effect(mo, **kwargs):
-            self.assertEqual(managed_object, mo._type)
-            self.assertEqual(managed_object, mo.value)
+            self.assertEqual(managed_object, vim_util.get_moref_type(mo))
+            self.assertEqual(managed_object, vim_util.get_moref_value(mo))
             fault = mock.Mock(faultstring="MyFault")
 
             fault_children = mock.Mock()
@@ -257,8 +257,8 @@ class ServiceTest(base.TestCase):
         managed_object = 'VirtualMachine'
 
         def side_effect(mo, **kwargs):
-            self.assertEqual(managed_object, mo._type)
-            self.assertEqual(managed_object, mo.value)
+            self.assertEqual(managed_object, vim_util.get_moref_type(mo))
+            self.assertEqual(managed_object, vim_util.get_moref_value(mo))
             raise httplib.CannotSendRequest()
 
         svc_obj = service.Service()
@@ -273,8 +273,8 @@ class ServiceTest(base.TestCase):
         managed_object = 'VirtualMachine'
 
         def side_effect(mo, **kwargs):
-            self.assertEqual(managed_object, mo._type)
-            self.assertEqual(managed_object, mo.value)
+            self.assertEqual(managed_object, vim_util.get_moref_type(mo))
+            self.assertEqual(managed_object, vim_util.get_moref_value(mo))
             raise httplib.ResponseNotReady()
 
         svc_obj = service.Service()
@@ -289,8 +289,8 @@ class ServiceTest(base.TestCase):
         managed_object = 'VirtualMachine'
 
         def side_effect(mo, **kwargs):
-            self.assertEqual(managed_object, mo._type)
-            self.assertEqual(managed_object, mo.value)
+            self.assertEqual(managed_object, vim_util.get_moref_type(mo))
+            self.assertEqual(managed_object, vim_util.get_moref_value(mo))
             raise httplib.CannotSendHeader()
 
         svc_obj = service.Service()
@@ -305,8 +305,8 @@ class ServiceTest(base.TestCase):
         managed_object = 'VirtualMachine'
 
         def side_effect(mo, **kwargs):
-            self.assertEqual(managed_object, mo._type)
-            self.assertEqual(managed_object, mo.value)
+            self.assertEqual(managed_object, vim_util.get_moref_type(mo))
+            self.assertEqual(managed_object, vim_util.get_moref_value(mo))
             raise requests.ConnectionError()
 
         svc_obj = service.Service()
@@ -321,8 +321,8 @@ class ServiceTest(base.TestCase):
         managed_object = 'VirtualMachine'
 
         def side_effect(mo, **kwargs):
-            self.assertEqual(managed_object, mo._type)
-            self.assertEqual(managed_object, mo.value)
+            self.assertEqual(managed_object, vim_util.get_moref_type(mo))
+            self.assertEqual(managed_object, vim_util.get_moref_value(mo))
             raise requests.HTTPError()
 
         svc_obj = service.Service()
@@ -344,8 +344,8 @@ class ServiceTest(base.TestCase):
         managed_object = 'VirtualMachine'
 
         def side_effect(mo, **kwargs):
-            self.assertEqual(managed_object, mo._type)
-            self.assertEqual(managed_object, mo.value)
+            self.assertEqual(managed_object, vim_util.get_moref_type(mo))
+            self.assertEqual(managed_object, vim_util.get_moref_value(mo))
             raise Exception(message)
 
         svc_obj = service.Service()
@@ -377,7 +377,7 @@ class ServiceTest(base.TestCase):
         cookie = mock.Mock()
         cookie.name = 'vmware_soap_session'
         cookie.value = cookie_value
-        svc_obj.client.options.transport.cookiejar = [cookie]
+        svc_obj.client.cookiejar = [cookie]
         self.assertEqual(cookie_value, svc_obj.get_http_cookie())
 
     def test_get_session_cookie_with_no_cookie(self):
@@ -385,7 +385,7 @@ class ServiceTest(base.TestCase):
         cookie = mock.Mock()
         cookie.name = 'cookie'
         cookie.value = 'xyz'
-        svc_obj.client.options.transport.cookiejar = [cookie]
+        svc_obj.client.cookiejar = [cookie]
         self.assertIsNone(svc_obj.get_http_cookie())
 
     def test_set_soap_headers(self):
@@ -493,8 +493,7 @@ class RequestsTransportTest(base.TestCase):
         transport = service.RequestsTransport()
 
         url = 'file:///foo'
-        request = requests.PreparedRequest()
-        request.url = url
+        request = requests.Request('GET', url).prepare()
 
         data = b"Hello World"
         get_size_mock.return_value = len(data)
@@ -502,7 +501,6 @@ class RequestsTransportTest(base.TestCase):
         def read_mock():
             return data
 
-        builtin_open = 'builtins.open'
         open_mock = mock.MagicMock(name='file_handle',
                                    spec=open)
         file_spec = list(set(dir(io.TextIOWrapper)).union(
@@ -514,7 +512,7 @@ class RequestsTransportTest(base.TestCase):
         file_handle.read.side_effect = read_mock
         open_mock.return_value = file_handle
 
-        with mock.patch(builtin_open, open_mock, create=True):
+        with mock.patch('builtins.open', open_mock, create=True):
             resp = transport.session.send(request)
             self.assertEqual(data, resp.content)
 
